==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/he/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'משתמש זה יכול להיכנס',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'נכסים שהוקצו ל: שם',
    'bulk_update_warn'	=> 'אתה עומד לערוך את המאפיינים של: user_count משתמשים. שים לב שאינך יכול לשנות את תכונות המשתמש שלך באמצעות טופס זה, ועליך לבצע עריכה למשתמש שלך בנפרד.',
    'bulk_update_help'	=> 'טופס זה מאפשר לך לעדכן מספר משתמשים בו-זמנית. מלא רק את השדות שאתה צריך לשנות. כל השדות שנותרו ריקים יישארו ללא שינוי.',
    'current_assets'    => 'הנכסים נבדקים כעת למשתמש זה',
    'clone'             => 'משתמש משוכפל',
    'contact_user'      => 'שם איש קשר',
    'edit'              => 'ערוך משתמש',
    'filetype_info'     => 'סוגי קבצים מותרים הם png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, ו rar.',
    'history_user'      => 'היסטוריה עבור: שם',
	'info'				=> 'מידע',
    'restore_user'		=> 'לחץ כאן כדי לשחזר אותם.',
    'last_login'        => 'כניסה אחרונה',
    'ldap_config_text'  => 'הגדרות תצורה של LDAP נמצאות \'מנהל\'> \'הגדרות\'. המיקום הנבחר (אופציונלי) ייקבע עבור כל המשתמשים המיובאים.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'התוכנה נבדקה אל: שם',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'הצג משתמש: שם',
    'usercsv'           => 'קובץ CSV',
    'two_factor_admin_optin_help' => 'הגדרות מנהל המערכת הנוכחיות מאפשרות אכיפה סלקטיבית של אימות דו-גורמי.',
    'two_factor_enrolled' => 'רשם מכשיר 2FA',
    'two_factor_active'   => '2FA פעיל',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/he/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'משתמש זה יכול להיכנס',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'נכסים שהוקצו ל: שם',
    'bulk_update_warn'	=> 'אתה עומד לערוך את המאפיינים של: user_count משתמשים. שים לב שאינך יכול לשנות את תכונות המשתמש שלך באמצעות טופס זה, ועליך לבצע עריכה למשתמש שלך בנפרד.',
    'bulk_update_help'	=> 'טופס זה מאפשר לך לעדכן מספר משתמשים בו-זמנית. מלא רק את השדות שאתה צריך לשנות. כל השדות שנותרו ריקים יישארו ללא שינוי.',
    'current_assets'    => 'הנכסים נבדקים כעת למשתמש זה',
    'clone'             => 'משתמש משוכפל',
    'contact_user'      => 'שם איש קשר',
    'edit'              => 'ערוך משתמש',
    'filetype_info'     => 'סוגי קבצים מותרים הם png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, ו rar.',
    'history_user'      => 'היסטוריה עבור: שם',
    'info'				=> 'מידע',
    'restore_user'		=> 'לחץ כאן כדי לשחזר אותם.',
    'last_login'        => 'כניסה אחרונה',
    'ldap_config_text'  => 'הגדרות תצורה של LDAP נמצאות \'מנהל\'> \'הגדרות\'. המיקום הנבחר (אופציונלי) ייקבע עבור כל המשתמשים המיובאים.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'התוכנה נבדקה אל: שם',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'הצג משתמש: שם',
    'usercsv'           => 'קובץ CSV',
    'two_factor_admin_optin_help' => 'הגדרות מנהל המערכת הנוכחיות מאפשרות אכיפה סלקטיבית של אימות דו-גורמי.',
    'two_factor_enrolled' => 'רשם מכשיר 2FA',
    'two_factor_active'   => '2FA פעיל',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'אזהרה:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
